==> pandas_1.3.5+dfsg.orig.tar.xz: pandas-1.3.5/web/pandas/contribute.md <==
# Contribute to pandas

_pandas_ is and will always be **free**. To make the development sustainable, we need _pandas_ users, corporate
and individual, to support the development by providing their time and money.

You can find more information about current developers in the [team page](about/team.html),
and about current sponsors in the [sponsors page](about/sponsors.html).

<section>
    <div class="container mt-5">
      <div class="row text-center">
        <div class="col-md-4">
          <span class="fa-stack fa-4x">
            <i class="fas fa-circle fa-stack-2x pink"></i>
            <i class="fas fa-building fa-stack-1x fa-inverse"></i>
          </span>
          <h4 class="service-heading mt-3 font-weight-bold blue">Corporate support</h4>
          <p class="text-muted">
            pandas depends on companies and institutions using the software to support its development. Hiring
            people to work on pandas, or letting existing employees to contribute to the
            software. Or sponsoring pandas with funds, so the project can hire people to
            progress on the <a href="about/roadmap.html">pandas roadmap</a>.
          </p>
          <p>More information in the <a href="about/sponsors.html">sponsors page</a></p>
        </div>
        <div class="col-md-4">
          <span class="fa-stack fa-4x">
            <i class="fas fa-circle fa-stack-2x pink"></i>
            <i class="fas fa-users fa-stack-1x fa-inverse"></i>
          </span>
          <h4 class="service-heading mt-3 font-weight-bold blue">Individual contributors</h4>
          <p class="text-muted">
            pandas is mostly developed by volunteers. All kind of contributions are welcome,
            such as contributions to the code, to the website (including graphical designers),
            to the documentation (including translators) and others. There are tasks for all
            levels, including beginners.
          </p>
          <p>More information in the <a href="{{ base_url }}/docs/development/index.html">contributing page</a></p>
        </div>
        <div class="col-md-4">
          <span class="fa-stack fa-4x">
            <i class="fas fa-circle fa-stack-2x pink"></i>
            <i class="fas fa-dollar-sign fa-stack-1x fa-inverse"></i>
          </span>
          <h4 class="service-heading mt-3 font-weight-bold blue">Donations</h4>
          <p class="text-muted">
            Individual donations are appreciated, and are used for things like the project
            infrastructure, travel expenses for our volunteer contributors to attend
            the in-person sprints, or to give small grants to develop features.
          </p>
          <p>Make your donation in the <a href="donate.html">donate page</a></p>
        </div>
      </div>
    </div>
</section>

==> pandas_1.5.3+dfsg.orig.tar.xz: pandas-1.5.3/web/pandas/contribute.md <==
# Contribute to pandas

_pandas_ is and will always be **free**. To make the development sustainable, we need _pandas_ users, corporate
and individual, to support the development by providing their time and money.

You can find more information about current developers in the [team page](about/team.html),
and about current sponsors in the [sponsors page](about/sponsors.html).

<section>
    <div class="container mt-5">
      <div class="row text-center">
        <div class="col-md-4">
          <span class="fa-stack fa-4x">
            <i class="fas fa-circle fa-stack-2x pink"></i>
            <i class="fas fa-building fa-stack-1x fa-inverse"></i>
          </span>
          <h4 class="service-heading mt-3 fw-bold blue">Corporate support</h4>
          <p class="text-muted">
            pandas depends on companies and institutions using the software to support its development. Hiring
            people to work on pandas, or letting existing employees to contribute to the
            software. Or sponsoring pandas with funds, so the project can hire people to
            progress on the <a href="about/roadmap.html">pandas roadmap</a>.
          </p>
          <p>More information in the <a href="about/sponsors.html">sponsors page</a></p>
        </div>
        <div class="col-md-4">
          <span class="fa-stack fa-4x">
            <i class="fas fa-circle fa-stack-2x pink"></i>
            <i class="fas fa-users fa-stack-1x fa-inverse"></i>
          </span>
          <h4 class="service-heading mt-3 fw-bold blue">Individual contributors</h4>
          <p class="text-muted">
            pandas is mostly developed by volunteers. All kind of contributions are welcome,
            such as contributions to the code, to the website (including graphical designers),
            to the documentation (including translators) and others. There are tasks for all
            levels, including beginners.
          </p>
          <p>More information in the <a href="{{ base_url }}/docs/development/index.html">contributing page</a></p>
        </div>
        <div class="col-md-4">
          <span class="fa-stack fa-4x">
            <i class="fas fa-circle fa-stack-2x pink"></i>
            <i class="fas fa-dollar-sign fa-stack-1x fa-inverse"></i>
          </span>
          <h4 class="service-heading mt-3 fw-bold blue">Donations</h4>
          <p class="text-muted">
            Individual donations are appreciated, and are used for things like the project
            infrastructure, travel expenses for our volunteer contributors to attend
            the in-person sprints, or to give small grants to develop features.
          </p>
          <p>Make your donation in the <a href="donate.html">donate page</a></p>
        </div>
      </div>
    </div>
</section>
